---
title: "@push.rocks/smartlog-destination-clickhouse"
source: "gitea"
---
# @push.rocks/smartlog-destination-clickhouse
a smartlog destination pushing logs to clickhouse

## Install
To start using `@push.rocks/smartlog-destination-clickhouse`, you need to install it using npm (Node Package Manager). Run the following command in your terminal:

```bash
npm install @push.rocks/smartlog-destination-clickhouse --save
```

This command will download the package and add it as a dependency to your project's `package.json` file.

## Usage

`@push.rocks/smartlog-destination-clickhouse` enables your applications to push logs directly to a ClickHouse database. This can be extremely useful for applications needing to log large amounts of data efficiently and perform complex analytics on logged data.

To get started, you'll first need to import the necessary modules and initialize the smartlog destination for ClickHouse. Here's a step-by-step guide using TypeScript with ESM syntax:

### Step 1: Import Modules

First, you need to import the `SmartlogDestinationClickhouse` class from the package:

```typescript
import { SmartlogDestinationClickhouse } from '@push.rocks/smartlog-destination-clickhouse';
```

### Step 2: Initialize Smartlog Destination

Before you can push logs to ClickHouse, you need to create an instance of `SmartlogDestinationClickhouse` and start it. This involves providing configuration details for your ClickHouse instance.

```typescript
// Define ClickHouse configuration
const clickhouseConfig = {
  host: 'your_clickhouse_host',
  port: 8123, // default ClickHouse HTTP interface port
  db: 'your_database_name',
  user: 'your_clickhouse_user',
  password: 'your_clickhouse_password',
};

// Create and start the SmartlogDestinationClickhouse instance
const smartlogDestination = await SmartlogDestinationClickhouse.createAndStart(clickhouseConfig);
```

This setup initializes the connection to your ClickHouse database and prepares it for logging.

### Step 3: Log Handling

Now that the setup is complete, you can start handling logs. The `handleLog` method provided by `SmartlogDestinationClickhouse` allows you to push log packages to your ClickHouse database.

```typescript
import { ILogPackage } from '@push.rocks/smartlog-interfaces';

// Sample log package
const sampleLogPackage: ILogPackage<unknown> = {
  logLevel: 'info',
  message: 'This is a test log message',
  additionalData: {
    // Any additional data you wish to log
    key: 'value'
  }
};

// Handle log
await smartlogDestination.handleLog(sampleLogPackage);
```

This will push the log to your ClickHouse database, making it available for querying and analysis.

### Conclusion

By following these steps, you can efficiently push logs to a ClickHouse database using `@push.rocks/smartlog-destination-clickhouse`. This setup provides a powerful and scalable logging solution for modern applications, enabling complex analytics on logged data.

Remember to always manage your database connections responsibly and ensure you have appropriate logging levels and data retention policies in place to avoid overwhelming your database with excessive logging data.

## License and Legal Information

This repository contains open-source code that is licensed under the MIT License. A copy of the MIT License can be found in the [license](license) file within this repository. 

**Please note:** The MIT License does not grant permission to use the trade names, trademarks, service marks, or product names of the project, except as required for reasonable and customary use in describing the origin of the work and reproducing the content of the NOTICE file.

### Trademarks

This project is owned and maintained by Task Venture Capital GmbH. The names and logos associated with Task Venture Capital GmbH and any related products or services are trademarks of Task Venture Capital GmbH and are not included within the scope of the MIT license granted herein. Use of these trademarks must comply with Task Venture Capital GmbH's Trademark Guidelines, and any usage must be approved in writing by Task Venture Capital GmbH.

### Company Information

Task Venture Capital GmbH  
Registered at District court Bremen HRB 35230 HB, Germany

For any legal inquiries or if you require further information, please contact us via email at hello@task.vc.

By using this repository, you acknowledge that you have read this section, agree to comply with its terms, and understand that the licensing of the code does not imply endorsement by Task Venture Capital GmbH of any derivative works.
