---
title: "@push.rocks/smartsystem"
source: "gitea"
---
# @push.rocks/smartsystem
interact with the system you are running on

## Install

To incorporate @push.rocks/smartsystem into your project, you'll need to install the package via npm. You can do this by running the following command in your project's root directory:

```bash
npm install @push.rocks/smartsystem --save
```

This command will download @push.rocks/smartsystem and add it to your project's `package.json` file as a dependency.

## Usage

The `@push.rocks/smartsystem` module offers a convenient way to interact with the system your application is running on. Below are detailed examples that demonstrate how to utilize its full potential. These examples are written in TypeScript and showcase different cases and features of the module.

### Getting Started

First, ensure that you are importing the module correctly in your TypeScript file:

```typescript
import { Smartsystem } from '@push.rocks/smartsystem';
```

### Creating an Instance of Smartsystem

To use the functionalities provided by `@push.rocks/smartsystem`, you need to create a new instance of the `Smartsystem` class.

```typescript
const mySystem = new Smartsystem();
```

### Accessing Environment Variables

`@push.rocks/smartsystem` integrates with `@pushrocks/smartenv` to provide an easy way to handle environment variables.

```typescript
console.log(mySystem.env.getEnvVars());
```

### Getting CPU Information

You can retrieve information about the CPUs of the system:

```typescript
console.log(mySystem.cpus[0]); // Logs details about the first CPU
```

### Working with Network Interfaces

The module allows you to work with network interfaces, making use of `@pushrocks/smartnetwork`:

```typescript
(async () => {
  console.log(await mySystem.network.getNetworkInfo());
})();
```

### System Information

For more detailed system information such as hardware specs or software versions, `@push.rocks/smartsystem` relies on the `systeminformation` library:

```typescript
(async () => {
  console.log(await mySystem.information.system());
  // Output detailed information about the system like manufacturer, model, etc.

  console.log(await mySystem.information.osInfo());
  // Output detailed information about the operating system
})();
```

### Real-World Scenarios

Now that we've covered the basics let's dive into some real-world applications:

#### Monitoring System Load

You can monitor the current load on the system to make decisions or trigger actions when the system is under heavy use:

```typescript
(async () => {
  const systemLoad = await mySystem.information.currentLoad();
  if (systemLoad.currentLoad > 80) {
    console.log("High system load detected. Consider scaling or optimizing your applications.");
  }
})();
```

#### Network Monitoring

It's often useful to keep an eye on network interfaces, especially when diagnosing connectivity issues or monitoring network traffic:

```typescript
(async () => {
  const defaultInterface = await mySystem.information.networkInterfaceDefault();
  const interfaceStats = await mySystem.information.networkStats(defaultInterface);
  console.log(interfaceStats);
  // Use this information to alert on unusual traffic patterns or drops in speed.
})();
```

### Conclusion

`@push.rocks/smartsystem` offers a comprehensive toolkit for interacting with the underlying system your Node.js application runs on. From retrieving environment variables and CPU information to monitoring network interfaces and system load, this module provides everything you need to ensure your application can intelligently respond to its operating environment.

Remember, the examples above only scratch the surface of what's possible with `@push.rocks/smartsystem`. For more detailed documentation on all available methods and their capabilities, refer to the [official documentation](https://pushrocks.gitlab.io/smartsystem/).

## License and Legal Information

This repository contains open-source code that is licensed under the MIT License. A copy of the MIT License can be found in the [license](license) file within this repository. 

**Please note:** The MIT License does not grant permission to use the trade names, trademarks, service marks, or product names of the project, except as required for reasonable and customary use in describing the origin of the work and reproducing the content of the NOTICE file.

### Trademarks

This project is owned and maintained by Task Venture Capital GmbH. The names and logos associated with Task Venture Capital GmbH and any related products or services are trademarks of Task Venture Capital GmbH and are not included within the scope of the MIT license granted herein. Use of these trademarks must comply with Task Venture Capital GmbH's Trademark Guidelines, and any usage must be approved in writing by Task Venture Capital GmbH.

### Company Information

Task Venture Capital GmbH  
Registered at District court Bremen HRB 35230 HB, Germany

For any legal inquiries or if you require further information, please contact us via email at hello@task.vc.

By using this repository, you acknowledge that you have read this section, agree to comply with its terms, and understand that the licensing of the code does not imply endorsement by Task Venture Capital GmbH of any derivative works.
